==> gradle-7.3-rc-1-src.zip: gradle-7.3-rc-1/subprojects/core/src/main/java/org/gradle/api/internal/tasks/AbstractTaskFilePropertyRegistration.java <==
/*
 * Copyright 2019 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.api.internal.tasks;

import org.gradle.api.internal.tasks.properties.ContentTracking;

public abstract class AbstractTaskFilePropertyRegistration implements TaskPropertyRegistration {
    private String propertyName;
    private boolean optional;
    private ContentTracking contentTracking = ContentTracking.TRACKED;
    private final StaticValue value;

    public AbstractTaskFilePropertyRegistration(StaticValue value) {
        this.value = value;
    }

    @Override
    public String getPropertyName() {
        return propertyName;
    }

    @Override
    public StaticValue getValue() {
        return value;
    }

    @Override
    public boolean isOptional() {
        return optional;
    }

    public void setPropertyName(String propertyName) {
        this.propertyName = TaskPropertyUtils.checkPropertyName(propertyName);
    }

    public void setOptional(boolean optional) {
        this.optional = optional;
    }

    public ContentTracking getContentTracking() {
        return contentTracking;
    }

    public void setContentTracking(ContentTracking contentTracking) {
        this.contentTracking = contentTracking;
    }
}

==> gradle-8.9-src.zip: gradle-8.9/subprojects/core/src/main/java/org/gradle/api/internal/tasks/AbstractTaskFilePropertyRegistration.java <==
/*
 * Copyright 2019 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.api.internal.tasks;

import org.gradle.internal.properties.StaticValue;

public abstract class AbstractTaskFilePropertyRegistration implements TaskPropertyRegistration {
    private String propertyName;
    private boolean optional;
    private final StaticValue value;

    public AbstractTaskFilePropertyRegistration(StaticValue value) {
        this.value = value;
    }

    @Override
    public String getPropertyName() {
        return propertyName;
    }

    @Override
    public StaticValue getValue() {
        return value;
    }

    @Override
    public boolean isOptional() {
        return optional;
    }

    public void setPropertyName(String propertyName) {
        if (propertyName.isEmpty()) {
            throw new IllegalArgumentException("Property name must not be empty string");
        }
        this.propertyName = propertyName;
    }

    public void setOptional(boolean optional) {
        this.optional = optional;
    }
}
